@@ -313,7 +313,7 @@ def addResource(apiInstance, appInstance):
 def initialize(apiInstance, appInstance):
     log.success(initialize, 'ApiKeyManager is running')
 
-def onHttpRequestClose(apiInstance, appInstance):
+def afterHttpRequest(apiInstance, appInstance):
     ...
 
 def onShutdown(apiInstance, appInstance):
